==> zio-aws-devicefarm_3-5.17.112.1-sources.jar: zio/aws/devicefarm/model/Resolution.scala <==
package zio.aws.devicefarm.model
import zio.aws.devicefarm.model.primitives.Integer
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters.*
final case class Resolution(
    width: Option[Integer] = None,
    height: Option[Integer] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.devicefarm.model.Resolution = {
    import Resolution.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.devicefarm.model.Resolution
      .builder()
      .optionallyWith(
        width.map(value => Integer.unwrap(value): java.lang.Integer)
      )(_.width)
      .optionallyWith(
        height.map(value => Integer.unwrap(value): java.lang.Integer)
      )(_.height)
      .build()
  }
  def asReadOnly: zio.aws.devicefarm.model.Resolution.ReadOnly =
    zio.aws.devicefarm.model.Resolution.wrap(buildAwsValue())
}
object Resolution {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.devicefarm.model.Resolution
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.devicefarm.model.Resolution =
      zio.aws.devicefarm.model
        .Resolution(width.map(value => value), height.map(value => value))
    def width: Option[Integer]
    def height: Option[Integer]
    def getWidth: ZIO[Any, AwsError, Integer] =
      AwsError.unwrapOptionField("width", width)
    def getHeight: ZIO[Any, AwsError, Integer] =
      AwsError.unwrapOptionField("height", height)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.devicefarm.model.Resolution
  ) extends zio.aws.devicefarm.model.Resolution.ReadOnly {
    override val width: Option[Integer] = scala
      .Option(impl.width())
      .map(value => zio.aws.devicefarm.model.primitives.Integer(value))
    override val height: Option[Integer] = scala
      .Option(impl.height())
      .map(value => zio.aws.devicefarm.model.primitives.Integer(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.devicefarm.model.Resolution
  ): zio.aws.devicefarm.model.Resolution.ReadOnly = new Wrapper(impl)
}

==> zio-aws-devicefarm_3-5.17.162.2-sources.jar: zio/aws/devicefarm/model/Resolution.scala <==
package zio.aws.devicefarm.model
import zio.aws.devicefarm.model.primitives.Integer
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters.*
final case class Resolution(
    width: Optional[Integer] = Optional.Absent,
    height: Optional[Integer] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.devicefarm.model.Resolution = {
    import Resolution.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.devicefarm.model.Resolution
      .builder()
      .optionallyWith(width.map(value => value: java.lang.Integer))(_.width)
      .optionallyWith(height.map(value => value: java.lang.Integer))(_.height)
      .build()
  }
  def asReadOnly: zio.aws.devicefarm.model.Resolution.ReadOnly =
    zio.aws.devicefarm.model.Resolution.wrap(buildAwsValue())
}
object Resolution {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.devicefarm.model.Resolution
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.devicefarm.model.Resolution =
      zio.aws.devicefarm.model
        .Resolution(width.map(value => value), height.map(value => value))
    def width: Optional[Integer]
    def height: Optional[Integer]
    def getWidth: ZIO[Any, AwsError, Integer] =
      AwsError.unwrapOptionField("width", width)
    def getHeight: ZIO[Any, AwsError, Integer] =
      AwsError.unwrapOptionField("height", height)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.devicefarm.model.Resolution
  ) extends zio.aws.devicefarm.model.Resolution.ReadOnly {
    override val width: Optional[Integer] = zio.aws.core.internal
      .optionalFromNullable(impl.width())
      .map(value => value: Integer)
    override val height: Optional[Integer] = zio.aws.core.internal
      .optionalFromNullable(impl.height())
      .map(value => value: Integer)
  }
  def wrap(
      impl: software.amazon.awssdk.services.devicefarm.model.Resolution
  ): zio.aws.devicefarm.model.Resolution.ReadOnly = new Wrapper(impl)
}
